@@ -22,7 +22,7 @@ class Referencer:
         """
         Sets references to specific component.
 
-        To set references components must implement [[IReferenceable]] interface.
+        To set references components must implement :class:`IReferenceable <pip_services3_commons.refer.IReferenceable.IReferenceable>` interface.
         If they don't the call to this method has no effect.
 
         :param references: the references to be set.
@@ -37,7 +37,7 @@ class Referencer:
         """
         Sets references to multiple components.
 
-        To set references components must implement [[IReferenceable]] interface.
+        To set references components must implement :class:`IReferenceable <pip_services3_commons.refer.IReferenceable.IReferenceable>` interface.
         If they don't the call to this method has no effect.
 
         :param references: the references to be set.
@@ -55,7 +55,7 @@ class Referencer:
         """
         Unsets references in specific component.
 
-        To unset references components must implement [[IUnreferenceable]] interface.
+        To unset references components must implement :class:`IUnreferenceable <pip_services3_commons.refer.IUnreferenceable.IUnreferenceable>` interface.
         If they don't the call to this method has no effect.
 
         :param component: the component to unset references.
@@ -68,7 +68,7 @@ class Referencer:
         """
         Unsets references in multiple components.
 
-        To unset references components must implement [[IUnreferenceable]] interface.
+        To unset references components must implement :class:`IUnreferenceable <pip_services3_commons.refer.IUnreferenceable.IUnreferenceable>` interface.
         If they don't the call to this method has no effect.
 
         :param components: the list of components, whose references must be cleared.
