@@ -16,7 +16,7 @@ class ObjectReader:
     """
     Helper class to perform property introspection and dynamic reading.
 
-    In contrast to [[PropertyReflector]] which only introspects regular objects,
+    In contrast to :class:`PropertyReflector <pip_services3_commons.reflect.PropertyReflector.PropertyReflector>` which only introspects regular objects,
     this ObjectReader is also able to handle maps and arrays.
 
     For maps properties are key-pairs identified by string keys,
@@ -29,6 +29,9 @@ class ObjectReader:
     this ObjectReader treats all property names as case insensitive.
 
     Example:
+
+    .. code-block:: python
+    
         myObj = MyObject()
 
         properties = ObjectReader.get_property_names()
